pub struct PerformanceMonitoringServices(/* private fields */);Implementations
Sourceimpl PerformanceMonitoringServices
impl PerformanceMonitoringServices
pub fn current_gpu_metrics(&self, gpu: &Gpu) -> Result<GpuMetrics>
pub fn sampling_interval_range(&self) -> Result<ADLX_IntRange>
Sourcepub fn set_sampling_interval(&mut self, interval_in_ms: i32) -> Result<()>
pub fn set_sampling_interval(&mut self, interval_in_ms: i32) -> Result<()>
interval_in_ms must be in the range provided by Self::sampling_interval_range().
pub fn sampling_interval(&self) -> Result<i32>
pub fn max_performance_metrics_history_range(&self) -> Result<ADLX_IntRange>
Sourcepub fn set_max_performance_metrics_history_size(
&mut self,
size_in_sec: i32,
) -> Result<()>
pub fn set_max_performance_metrics_history_size( &mut self, size_in_sec: i32, ) -> Result<()>
size_in_sec must be in the range provided by Self::max_performance_metrics_history_range().
pub fn max_performance_metrics_history_size(&self) -> Result<i32>
pub fn clear_performance_metrics_history(&self) -> Result<()>
pub fn current_performance_metrics_history_size_in_sec(&self) -> Result<i32>
pub fn start_performance_tracking(&mut self) -> Result<()>
pub fn stop_performance_tracking(&mut self) -> Result<()>
pub fn gpu_metrics_history( &self, gpu: &Gpu, start_in_ms: i32, stop_in_ms: i32, ) -> Result<GpuMetricsList>
pub fn supported_gpu_metrics(&self, gpu: &Gpu) -> Result<GpuMetricsSupport>